#[repr(i32)]pub enum IdentityProvider {
None = 0,
Auth0 = 1,
Google = 2,
Microsoft = 3,
Okta = 4,
Facebook = 5,
Github = 6,
X = 7,
Linkedin = 8,
Apple = 9,
}Expand description
IdentityProvider enumerates all identity providers. DEPRECATED: Client initiates auth flow outside of this API.
Variants
None = 0
Auth0 = 1
Google = 2
Microsoft = 3
Okta = 4
Facebook = 5
Github = 6
X = 7
Previously Twitter
Linkedin = 8
Apple = 9
Implementations
Sourceimpl IdentityProvider
impl IdentityProvider
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<IdentityProvider>
pub fn from_str_name(value: &str) -> Option<IdentityProvider>
Creates an enum from field names used in the ProtoBuf definition.