pub struct IngestSuccess {
pub ingested_swids: Vec<String>,
pub ingested_schemas: Vec<String>,
}Expand description
IngestSuccess is the successful response from an ingest request. Ingested SWIDs are the new documents inserted. Ingested schemas are the new schemas inserted (if any). If there is an error, the error is returned.
Fields
ingested_swids: Vec<String>ingested_schemas: Vec<String>Trait Implementations
Sourceimpl Clone for IngestSuccess
impl Clone for IngestSuccess
Sourcefn clone(&self) -> IngestSuccess
fn clone(&self) -> IngestSuccess
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IngestSuccess
impl Debug for IngestSuccess
Sourceimpl Default for IngestSuccess
impl Default for IngestSuccess
Sourcefn default() -> IngestSuccess
fn default() -> IngestSuccess
Returns the “default value” for a type. Read more
Sourceimpl Message for IngestSuccess
impl Message for IngestSuccess
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for IngestSuccess
impl PartialEq for IngestSuccess
Sourcefn eq(&self, other: &IngestSuccess) -> bool
fn eq(&self, other: &IngestSuccess) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for IngestSuccess